Struct WriteHalf
pub struct WriteHalf<T> {
handle: BiLock<T>,
}Expand description
The writable half of an object returned from AsyncRead::split.
Fields
handle: BiLock<T>Implementations
impl<T> WriteHalf<T>
impl<T> WriteHalf<T>
pub fn is_pair_of(&self, other: &ReadHalf<T>) -> bool
pub fn is_pair_of(&self, other: &ReadHalf<T>) -> bool
Checks if this WriteHalf and some ReadHalf were split from the same stream.
impl<T> WriteHalf<T>where
T: Unpin,
impl<T> WriteHalf<T>where
T: Unpin,
pub fn reunite(self, other: ReadHalf<T>) -> Result<T, ReuniteError<T>>
pub fn reunite(self, other: ReadHalf<T>) -> Result<T, ReuniteError<T>>
Attempts to put the two “halves” of a split AsyncRead + AsyncWrite back
together. Succeeds only if the ReadHalf<T> and WriteHalf<T> are
a matching pair originating from the same call to AsyncReadExt::split.